@@ -115,45 +115,45 @@ class Recurrence:
         """This property defines a rule or repeating pattern for recurring events.
 
         :param freq:
-                identifies the type of recurrence rule. Possible values are SECONDLY, HOURLY,
+                Identifies the type of recurrence rule. Possible values are SECONDLY, HOURLY,
                 MINUTELY, DAILY, WEEKLY, MONTHLY, YEARLY. Default: DAILY
         :param interval:
-                positive integer representing how often the recurrence rule repeats
+                Positive integer representing how often the recurrence rule repeats
         :param count:
-                number of occurrences at which to range-bound the recurrence
+                Number of occurrences at which to range-bound the recurrence
         :param until:
-                end date of recurrence
+                End date of recurrence
         :param by_second:
-                second or list of seconds within a minute. Valid values are 0 to 60
+                Second or list of seconds within a minute. Valid values are 0 to 60
         :param by_minute:
-                minute or list of minutes within a hour. Valid values are 0 to 59
+                Minute or list of minutes within a hour. Valid values are 0 to 59
         :param by_hour:
-                hour or list of hours of the day. Valid values are 0 to 23
+                Hour or list of hours of the day. Valid values are 0 to 23
         :param by_week_day:
-                day or list of days of the week.
+                Day or list of days of the week.
                 Possible values: :py:class:~SUNDAY, :py:class:~MONDAY, :py:class:~TUESDAY, :py:class:~WEDNESDAY,
                 :py:class:~THURSDAY ,:py:class:~FRIDAY, :py:class:~SATURDAY
         :param by_month_day:
-                day or list of days of the month. Valid values are 1 to 31 or -31 to -1.
+                Day or list of days of the month. Valid values are 1 to 31 or -31 to -1.
                 For example, -10 represents the tenth to the last day of the month.
         :param by_year_day:
-                day or list of days of the year. Valid values are 1 to 366 or -366 to -1.
+                Day or list of days of the year. Valid values are 1 to 366 or -366 to -1.
                 For example, -1 represents the last day of the year.
         :param by_week:
-                ordinal or list of ordinals specifying weeks of the year. Valid values are 1 to 53 or -53 to -1.
+                Ordinal or list of ordinals specifying weeks of the year. Valid values are 1 to 53 or -53 to -1.
         :param by_month:
-                month or list of months of the year. Valid values are 1 to 12.
+                Month or list of months of the year. Valid values are 1 to 12.
         :param by_set_pos:
-                value or list of values which corresponds to the nth occurrence within the set of events
+                Value or list of values which corresponds to the nth occurrence within the set of events
                 specified by the rule. Valid values are 1 to 366 or -366 to -1.
                 It can only be used in conjunction with another by_xxx parameter.
         :param week_start:
-                the day on which the workweek starts.
+                The day on which the workweek starts.
                 Possible values: :py:class:~SUNDAY, :py:class:~MONDAY, :py:class:~TUESDAY, :py:class:~WEDNESDAY,
                 :py:class:~THURSDAY ,:py:class:~FRIDAY, :py:class:~SATURDAY
 
         :return:
-                string representing specified recurrence rule in `RRULE format`_.
+                String representing specified recurrence rule in `RRULE format`_.
 
         .. note:: If none of the by_day, by_month_day, or by_year_day are specified, the day is gotten from start date.
 
@@ -183,45 +183,45 @@ class Recurrence:
         """This property defines an exclusion rule or repeating pattern for recurring events.
 
         :param freq:
-                identifies the type of recurrence rule. Possible values are SECONDLY, HOURLY,
+                Identifies the type of recurrence rule. Possible values are SECONDLY, HOURLY,
                 MINUTELY, DAILY, WEEKLY, MONTHLY, YEARLY. Default: DAILY
         :param interval:
-                positive integer representing how often the recurrence rule repeats
+                Positive integer representing how often the recurrence rule repeats
         :param count:
-                number of occurrences at which to range-bound the recurrence
+                Number of occurrences at which to range-bound the recurrence
         :param until:
-                end date of recurrence
+                End date of recurrence
         :param by_second:
-                second or list of seconds within a minute. Valid values are 0 to 60
+                Second or list of seconds within a minute. Valid values are 0 to 60
         :param by_minute:
-                minute or list of minutes within a hour. Valid values are 0 to 59
+                Minute or list of minutes within a hour. Valid values are 0 to 59
         :param by_hour:
-                hour or list of hours of the day. Valid values are 0 to 23
+                Hour or list of hours of the day. Valid values are 0 to 23
         :param by_week_day:
-                day or list of days of the week.
+                Day or list of days of the week.
                 Possible values: :py:class:~SUNDAY, :py:class:~MONDAY, :py:class:~TUESDAY, :py:class:~WEDNESDAY,
                 :py:class:~THURSDAY ,:py:class:~FRIDAY, :py:class:~SATURDAY
         :param by_month_day:
-                day or list of days of the month. Valid values are 1 to 31 or -31 to -1.
+                Day or list of days of the month. Valid values are 1 to 31 or -31 to -1.
                 For example, -10 represents the tenth to the last day of the month.
         :param by_year_day:
-                day or list of days of the year. Valid values are 1 to 366 or -366 to -1.
+                Day or list of days of the year. Valid values are 1 to 366 or -366 to -1.
                 For example, -1 represents the last day of the year.
         :param by_week:
-                ordinal or list of ordinals specifying weeks of the year. Valid values are 1 to 53 or -53 to -1.
+                Ordinal or list of ordinals specifying weeks of the year. Valid values are 1 to 53 or -53 to -1.
         :param by_month:
-                month or list of months of the year. Valid values are 1 to 12.
+                Month or list of months of the year. Valid values are 1 to 12.
         :param by_set_pos:
-                value or list of values which corresponds to the nth occurrence within the set of events
+                Value or list of values which corresponds to the nth occurrence within the set of events
                 specified by the rule. Valid values are 1 to 366 or -366 to -1.
                 It can only be used in conjunction with another by_xxx parameter.
         :param week_start:
-                the day on which the workweek starts.
+                The day on which the workweek starts.
                 Possible values: :py:class:~SUNDAY, :py:class:~MONDAY, :py:class:~TUESDAY, :py:class:~WEDNESDAY,
                 :py:class:~THURSDAY ,:py:class:~FRIDAY, :py:class:~SATURDAY
 
         :return:
-                string representing specified recurrence rule in `RRULE format`_.
+                String representing specified recurrence rule in `RRULE format`_.
 
         .. note:: If none of the by_day, by_month_day, or by_year_day are specified, the day is gotten from start date.
 
@@ -235,8 +235,11 @@ class Recurrence:
     def dates(ds):
         """Converts date(s) set to RDATE format.
 
-        :param ds: date/datetime object or list of date/datetime objects
-        :return: RDATE string of dates.
+        :param ds:
+                date/datetime object or list of date/datetime objects
+
+        :return:
+                RDATE string of dates.
         """
         return 'RDATE;' + Recurrence._dates(ds)
 
@@ -244,10 +247,14 @@ class Recurrence:
     def times(dts, timezone=str(get_localzone())):
         """Converts datetime(s) set to RDATE format.
 
-        :param dts: datetime object or list of datetime objects
-        :param timezone: Timezone formatted as an IANA Time Zone Database name, e.g. "Europe/Zurich". By default,
-                         the computers local timezone is used if it is configured. UTC is used otherwise.
-        :return: RDATE string of datetimes with specified timezone.
+        :param dts:
+                datetime object or list of datetime objects
+        :param timezone:
+                Timezone formatted as an IANA Time Zone Database name, e.g. "Europe/Zurich". By default,
+                the computers local timezone is used if it is configured. UTC is used otherwise.
+
+        :return:
+                RDATE string of datetimes with specified timezone.
         """
         return 'RDATE;' + Recurrence._times(dts, timezone)
 
@@ -258,10 +265,14 @@ class Recurrence:
         Period is defined as tuple of starting date/datetime and ending date/datetime or duration as Duration object:
             (date/datetime, date/datetime/Duration)
 
-        :param ps: period or list of periods.
-        :param timezone: Timezone formatted as an IANA Time Zone Database name, e.g. "Europe/Zurich". By default,
-                         the computers local timezone is used if it is configured. UTC is used otherwise.
-        :return: RDATE string of periods.
+        :param ps:
+                Period or list of periods.
+        :param timezone:
+                Timezone formatted as an IANA Time Zone Database name, e.g. "Europe/Zurich". By default,
+                the computers local timezone is used if it is configured. UTC is used otherwise.
+
+        :return:
+                RDATE string of periods.
         """
         return 'RDATE;' + Recurrence._periods(ps, timezone)
 
@@ -269,8 +280,11 @@ class Recurrence:
     def exclude_dates(ds):
         """Converts date(s) set to EXDATE format.
 
-        :param ds: date/datetime object or list of date/datetime objects
-        :return: EXDATE string of dates.
+        :param ds:
+                date/datetime object or list of date/datetime objects
+
+        :return:
+                EXDATE string of dates.
         """
         return 'EXDATE;' + Recurrence._dates(ds)
 
@@ -278,10 +292,14 @@ class Recurrence:
     def exclude_times(dts, timezone=str(get_localzone())):
         """Converts datetime(s) set to EXDATE format.
 
-        :param dts: datetime object or list of datetime objects
-        :param timezone: Timezone formatted as an IANA Time Zone Database name, e.g. "Europe/Zurich". By default,
-                         the computers local timezone is used if it is configured. UTC is used otherwise.
-        :return: EXDATE string of datetimes with specified timezone.
+        :param dts:
+                datetime object or list of datetime objects
+        :param timezone:
+                Timezone formatted as an IANA Time Zone Database name, e.g. "Europe/Zurich". By default,
+                the computers local timezone is used if it is configured. UTC is used otherwise.
+
+        :return:
+                EXDATE string of datetimes with specified timezone.
         """
         return 'EXDATE;' + Recurrence._times(dts, timezone)
 
@@ -292,10 +310,14 @@ class Recurrence:
         Period is defined as tuple of starting date/datetime and ending date/datetime or duration as Duration object:
             (date/datetime, date/datetime/Duration)
 
-        :param ps: period or list of periods.
-        :param timezone: Timezone formatted as an IANA Time Zone Database name, e.g. "Europe/Zurich". By default,
-                         the computers local timezone is used if it is configured. UTC is used otherwise.
-        :return: EXDATE string of periods.
+        :param ps:
+                Period or list of periods.
+        :param timezone:
+                Timezone formatted as an IANA Time Zone Database name, e.g. "Europe/Zurich". By default,
+                the computers local timezone is used if it is configured. UTC is used otherwise.
+
+        :return:
+                EXDATE string of periods.
         """
         return 'EXDATE;' + Recurrence._periods(ps, timezone)
 
@@ -303,10 +325,14 @@ class Recurrence:
     def _times(dts, timezone=str(get_localzone())):
         """Converts datetime(s) set to RDATE format.
 
-        :param dts: datetime object or list of datetime objects
-        :param timezone: Timezone formatted as an IANA Time Zone Database name, e.g. "Europe/Zurich". By default,
-                         the computers local timezone is used if it is configured. UTC is used otherwise.
-        :return: RDATE string of datetimes with specified timezone.
+        :param dts:
+                datetime object or list of datetime objects
+        :param timezone:
+                Timezone formatted as an IANA Time Zone Database name, e.g. "Europe/Zurich". By default,
+                the computers local timezone is used if it is configured. UTC is used otherwise.
+
+        :return:
+                RDATE string of datetimes with specified timezone.
         """
 
         if not isinstance(dts, list):
@@ -325,8 +351,11 @@ class Recurrence:
     def _dates(ds):
         """Converts date(s) set to RDATE format.
 
-        :param ds: date/datetime object or list of date/datetime objects
-        :return: RDATE string of dates.
+        :param ds:
+                date/datetime object or list of date/datetime objects
+
+        :return:
+                RDATE string of dates.
         """
         if not isinstance(ds, list):
             ds = [ds]
@@ -345,10 +374,14 @@ class Recurrence:
         Period is defined as tuple of starting date/datetime and ending date/datetime or duration as Duration object:
             (date/datetime, date/datetime/Duration)
 
-        :param ps: period or list of periods.
-        :param timezone: Timezone formatted as an IANA Time Zone Database name, e.g. "Europe/Zurich". By default,
-                         the computers local timezone is used if it is configured. UTC is used otherwise.
-        :return: RDATE string of periods.
+        :param ps:
+                Period or list of periods.
+        :param timezone:
+                Timezone formatted as an IANA Time Zone Database name, e.g. "Europe/Zurich". By default,
+                the computers local timezone is used if it is configured. UTC is used otherwise.
+
+        :return:
+                RDATE string of periods.
         """
         if not isinstance(ps, list):
             ps = [ps]
@@ -392,45 +425,45 @@ class Recurrence:
         """This property defines a rule or repeating pattern for recurring events.
 
         :param freq:
-                identifies the type of recurrence rule. Possible values are SECONDLY, HOURLY,
+                Identifies the type of recurrence rule. Possible values are SECONDLY, HOURLY,
                 MINUTELY, DAILY, WEEKLY, MONTHLY, YEARLY. Default: DAILY
         :param interval:
-                positive integer representing how often the recurrence rule repeats
+                Positive integer representing how often the recurrence rule repeats
         :param count:
-                number of occurrences at which to range-bound the recurrence
+                Number of occurrences at which to range-bound the recurrence
         :param until:
-                end date of recurrence
+                End date of recurrence
         :param by_second:
-                second or list of seconds within a minute. Valid values are 0 to 60
+                Second or list of seconds within a minute. Valid values are 0 to 60
         :param by_minute:
-                minute or list of minutes within a hour. Valid values are 0 to 59
+                Minute or list of minutes within a hour. Valid values are 0 to 59
         :param by_hour:
-                hour or list of hours of the day. Valid values are 0 to 23
+                Hour or list of hours of the day. Valid values are 0 to 23
         :param by_week_day:
-                day or list of days of the week.
+                Day or list of days of the week.
                 Possible values: :py:class:~SUNDAY, :py:class:~MONDAY, :py:class:~TUESDAY, :py:class:~WEDNESDAY,
                 :py:class:~THURSDAY ,:py:class:~FRIDAY, :py:class:~SATURDAY
         :param by_month_day:
-                day or list of days of the month. Valid values are 1 to 31 or -31 to -1.
+                Day or list of days of the month. Valid values are 1 to 31 or -31 to -1.
                 For example, -10 represents the tenth to the last day of the month.
         :param by_year_day:
-                day or list of days of the year. Valid values are 1 to 366 or -366 to -1.
+                Day or list of days of the year. Valid values are 1 to 366 or -366 to -1.
                 For example, -1 represents the last day of the year.
         :param by_week:
-                ordinal or list of ordinals specifying weeks of the year. Valid values are 1 to 53 or -53 to -1.
+                Ordinal or list of ordinals specifying weeks of the year. Valid values are 1 to 53 or -53 to -1.
         :param by_month:
-                month or list of months of the year. Valid values are 1 to 12.
+                Month or list of months of the year. Valid values are 1 to 12.
         :param by_set_pos:
-                value or list of values which corresponds to the nth occurrence within the set of events
+                Value or list of values which corresponds to the nth occurrence within the set of events
                 specified by the rule. Valid values are 1 to 366 or -366 to -1.
                 It can only be used in conjunction with another by_xxx parameter.
         :param week_start:
-                the day on which the workweek starts.
+                The day on which the workweek starts.
                 Possible values: :py:class:~SUNDAY, :py:class:~MONDAY, :py:class:~TUESDAY, :py:class:~WEDNESDAY,
                 :py:class:~THURSDAY ,:py:class:~FRIDAY, :py:class:~SATURDAY
 
         :return:
-                string representing specified recurrence rule in `RRULE format`_.
+                String representing specified recurrence rule in `RRULE format`_.
 
         .. note:: If none of the by_day, by_month_day, or by_year_day are specified, the day is gotten from start date.
 
